@@ -5,6 +5,7 @@ import (
 	"github.com/spf13/cobra"
 
 	"github.com/superfly/flyctl/internal/command"
+	"github.com/superfly/flyctl/internal/command/extensions/enveloop"
 	"github.com/superfly/flyctl/internal/command/extensions/kafka"
 	"github.com/superfly/flyctl/internal/command/extensions/kubernetes"
 	sentry_ext "github.com/superfly/flyctl/internal/command/extensions/sentry"
@@ -30,6 +31,7 @@ func New() (cmd *cobra.Command) {
 		kubernetes.New(),
 		kafka.New(),
 		vector.New(),
+		enveloop.New(),
 	)
 	return
 }
