@@ -3,12 +3,15 @@ package launch
 import (
 	"context"
 	"fmt"
+	"path/filepath"
+	"strings"
 
 	fly "github.com/superfly/fly-go"
 	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/flapsutil"
+	"github.com/superfly/flyctl/internal/flyutil"
 	"github.com/superfly/flyctl/internal/tracing"
 	"github.com/superfly/flyctl/iostreams"
 )
@@ -79,8 +82,14 @@ func (state *launchState) Launch(ctx context.Context) error {
 	}
 
 	// Finally write application configuration to fly.toml
-	state.appConfig.SetConfigFilePath(state.configPath)
-	if err := state.appConfig.WriteToDisk(ctx, state.configPath); err != nil {
+	configPath := state.configPath
+	if flag.GetBool(ctx, "json") {
+		configPath = strings.TrimSuffix(configPath, filepath.Ext(configPath)) + ".json"
+	} else if flag.GetBool(ctx, "yaml") {
+		configPath = strings.TrimSuffix(configPath, filepath.Ext(configPath)) + ".yaml"
+	}
+	state.appConfig.SetConfigFilePath(configPath)
+	if err := state.appConfig.WriteToDisk(ctx, configPath); err != nil {
 		return err
 	}
 
@@ -144,7 +153,7 @@ func (state *launchState) updateConfig(ctx context.Context) {
 
 // createApp creates the fly.io app for the plan
 func (state *launchState) createApp(ctx context.Context) (*fly.App, error) {
-	apiClient := fly.ClientFromContext(ctx)
+	apiClient := flyutil.ClientFromContext(ctx)
 	org, err := state.Org(ctx)
 	if err != nil {
 		return nil, err
